<?php
/**
 * @file
 * Photowall style plugin for the Views module.
 */

/**
  * Implements a style type plugin for the Views module.
  */
class views_plugin_style_photowall extends views_plugin_style {

  /**
   * Set default options.
   */
  function option_definition() {
    $options = parent::option_definition();

    $options += array(
      'zoom_factor' => array('default' => '1.5'),
      'zoom_timeout' => array('default' => '500'),
      'zoom_image_border' => array('default' => '5'),
      'zoom_duration' => array('default' => '100'),
      'show_box' => array('default' => TRUE),
      'show_box_social' => array('default' => TRUE),
      'padding' => array('default' => '5'),
      'line_max_height' => array('default' => '150'),
    );

    return $options;
  }

  /**
   * Show a form to edit the style options.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['photowall'] = array(
      '#type' => 'fieldset',
      '#title' => 'Photowall',
    );

    $form['photowall']['zoom_factor'] = array(
      '#title' => t('Zoom factor'),
      '#type' => 'textfield',
      '#size' => 4,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Enter value between 1.3 to 1.6 for better results.'),
      '#default_value' => $this->options['zoom_factor'],
    );
    $form['photowall']['zoom_timeout'] = array(
      '#title' => t('Zoom timeout'),
      '#type' => 'textfield',
      '#size' => 5,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Number of milliseconds for timeout before zoom.'),
      '#default_value' => $this->options['zoom_timeout'],
    );
    $form['photowall']['zoom_image_border'] = array(
      '#title' => t('Zoom image border'),
      '#type' => 'textfield',
      '#size' => 4,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Zoomed image border size.'),
      '#default_value' => $this->options['zoom_image_border'],
    );
    $form['photowall']['zoom_duration'] = array(
      '#title' => t('Zoom duration'),
      '#type' => 'textfield',
      '#size' => 5,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Number of milliseconds for zoom duration time.'),
      '#default_value' => $this->options['zoom_duration'],
    );
    $form['photowall']['show_box'] = array(
      '#title' => t('Show box'),
      '#type' => 'checkbox',
      '#description' => t('Enable fullscreen mode.'),
      '#default_value' => $this->options['show_box'],
    );
    $form['photowall']['show_box_social'] = array(
      '#title' => t('Show social buttons'),
      '#type' => 'checkbox',
      '#description' => t('Show social buttons in fullscreen mode.'),
      '#default_value' => $this->options['show_box_social'],
    );
    $form['photowall']['padding'] = array(
      '#title' => t('Padding'),
      '#type' => 'textfield',
      '#size' => 4,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Padding between images in gallery.'),
      '#default_value' => $this->options['padding'],
    );
    $form['photowall']['line_max_height'] = array(
      '#title' => t('Maximum line height'),
      '#type' => 'textfield',
      '#size' => 5,
      '#element_validate' => array('element_validate_number'),
      '#required' => TRUE,
      '#description' => t('Maximum height of pictures line.'),
      '#default_value' => $this->options['line_max_height'],
    );
  }

  /**
   * Performs some cleanup tasks on the options array before saving it.
   */
  function options_submit(&$form, &$form_state) {
    $options = &$form_state['values']['style_options'];

    // Pull the fieldset values one level up
    $options += $options['photowall'];
    unset($options['photowall']);
  }

  /**
   * Searches for the image field to use.
   */
  function find_image_field() {
    foreach ($this->view->display_handler->get_handlers('field') as $id => $handler) {
      if (($handler instanceof views_handler_field_field) && ($handler->field_info['type'] == 'image')) {
        return $id;
        break;
      }
    }
    return FALSE;
  }

  /**
   * Render the display in this style.
   */
  function render() {
    $image_field = $this->find_image_field();
    if ($image_field === FALSE) {
      drupal_set_message(t('Style @style requires an image field to be added.', array('@style' => $this->definition['title'])), 'error');
      return;
    }

    // Group the rows according to the grouping field, if specified.
    $sets = $this->render_grouping($this->view->result, $this->options['grouping']);

    // Render each group separately and concatenate.
    $output = '';
    foreach ($sets as $title => $rows) {
      $output .= theme($this->theme_functions(),
        array(
          'view' => $this->view,
          'options' => $this->options,
          'img_field_name' => $image_field,
          'rows' => $rows,
          'title' => $title,
        )
      );
    }
    return $output;
  }
}
